@@ -43,6 +43,7 @@ def check_for_acceptable_exit_code(
     exit_code: int | None = None,
     acceptable_exit_codes: tuple[int, ...] = (0,),
     verbose: bool = True,
+    raise_error: bool = False,
 ):
     debug_print(
         "{} Exit code".format(identifier),
@@ -61,7 +62,10 @@ def check_for_acceptable_exit_code(
             c=exit_code,
             ac=acceptable_exit_codes,
         )
-        raise ValueError(error_message) from None
+        if raise_error:
+            raise ValueError(error_message) from None
+        else:
+            return exit_code
     else:
         return exit_code
 
@@ -95,7 +99,8 @@ def get_bx_request(
 def inspect_bx_response(
     response,
     identifier: str,
-    acceptable_exit_codes: tuple[int, ...] = (0, 7),
+    acceptable_exit_codes: tuple[int, ...] = (0,),
+    inacceptable_exit_code_raise_error: bool = False,
     verbose: bool = True,
 ):
     # check potential error message
@@ -116,6 +121,7 @@ def inspect_bx_response(
         error_message=error_message,
         exit_code=exit_code,
         acceptable_exit_codes=acceptable_exit_codes,
+        raise_error=inacceptable_exit_code_raise_error,
     )
     return exit_code
 
@@ -127,9 +133,10 @@ def run_command(
     verbose: bool = True,
     cwd=None,
     shell: bool = True,
-    acceptable_exit_codes: tuple[int, ...] = (0,),
     reraise: bool = True,
     custom_exceptions: list | None = None,
+    acceptable_exit_codes: tuple[int, ...] = (0,),
+    inacceptable_exit_code_raise_error: bool = False,
 ):
 
     debug_print("{} command".format(identifier), command, verbose=verbose, long=False)
@@ -161,6 +168,7 @@ def run_command(
         error_message=stderr,
         exit_code=exit_code,
         acceptable_exit_codes=acceptable_exit_codes,
+        raise_error=inacceptable_exit_code_raise_error,
     )
     return exit_code
 
@@ -176,6 +184,7 @@ def run_bx_job(
     verbose: bool = True,
     reraise: bool = True,
     acceptable_exit_codes: tuple[int, ...] = (0,),
+    inacceptable_exit_code_raise_error: bool = False,
 ):
     # Initialize
     output_json = dict()
@@ -211,6 +220,7 @@ def run_bx_job(
     exit_code = inspect_bx_response(
         identifier=identifier,
         acceptable_exit_codes=acceptable_exit_codes,
+        inacceptable_exit_code_raise_error=inacceptable_exit_code_raise_error,
         verbose=verbose,
     )
 
